(* $Id: godi_win32.mli 805 2008-06-11 00:50:03Z gerd $  
 * ----------------------------------------------------------------------
 * Copyright 2008 by Gerd Stolpmann.
 *
 * This file is part of godi-tools.
 *
 * godi-tools is free software; you can redistribute it and/or modify it
 * under the conditions in the file LICENSE.
 *
 * godi-tools is distributed WITHOUT ANY WARRANTY, as detailed in the
 * file LICENSE.
*)

(* Registry: *)

type reg_handle
  (* A registry handle *)

type reg_value =
  | RV_BINARY of string
  | RV_DWORD of int32
  | RV_EXPAND_LZ of string
  | RV_LINK of string
  | RV_MULTI_SZ of string
  | RV_NONE
  | RV_QWORD of int64
  | RV_SZ of string
  (* For RV_SZ and RV_EXPAND_LZ trailing null bytes are stripped off.
     The other values are kept as-is
   *)

type reg_type =
  | RT_BINARY
  | RT_DWORD
  | RT_EXPAND_LZ
  | RT_LINK
  | RT_MULTI_SZ
  | RT_NONE
  | RT_QWORD
  | RT_SZ

exception Registry_error of string

val hkey_classes_root : reg_handle
val hkey_current_user : reg_handle
val hkey_local_machine : reg_handle
val hkey_users : reg_handle
  (* The root keys *)

val reg_open_key : reg_handle -> string -> reg_handle
  (* Open a sub key *)

(* val reg_open_current_user : unit -> reg_handle *)
  (* Opens the HKEY_CURRENT_USER key for the user of the current thread *)

val reg_close_key : reg_handle -> unit
  (* Closes the handle. The root keys must not be closed *)

val reg_query_value : reg_handle -> string -> reg_value
  (* reg_query_value hkey valuename: Returns the value data of the
     requested value
   *)

val reg_enum_key : reg_handle -> (string * string) list
  (* Returns the subkeys and their class names *)

val reg_enum_value : reg_handle -> (string * reg_type) list
  (* Returns the values and their types *)


(* Other *)

val get_logical_drives : unit -> int
  (* Get the bitmask enumerating the existing drives.
     See the Win32 function GetLogicalDrives.
   *)

val get_identity_information : string -> (int32 * int64)
  (* Returns the volume serial number and the file index in this volume.
     Both numbers identify the file uniquely
   *)

val sleep : float -> unit
  (* Sleeps for the number of seconds *)

val interrupt_sleep : unit -> unit
  (* Interrupts all ongoing sleeps, if any. This function can be called from
     a different thread
   *)

val generate_ctrl_c : unit -> unit
  (* Send a CTRL-C event to the console *)

val get_process_id : int -> int
  (* The number returned by "Unix.create_process" is not the real Windows
     process ID, but a handle to the process. This function converts to an
     official PID.
   *)

val peek_pipe : Unix.file_descr -> int
  (* Returns the number of bytes in the pipe buffer *)

val string_of_fd : Unix.file_descr -> string
  (* Return the handle as string (for debugging) *)
